#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-5vlTOmvuWkHDGOkj2fSbWn
key:                    sdl2-ttf-2.1.3-5vlTOmvuWkHDGOkj2fSbWn
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    7c294e1bb8ba78f0c63fbffb458e1d76
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-5vlTOmvuWkHDGOkj2fSbWn
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 harfbuzz m glib-2.0 atomic m sysprof-capture-4
    pcre2-8 pthread graphite2 freetype dl bz2 png16 m m z brotlidec
    brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include/freetype2 /usr/include/libpng16

depends:
    base-4.18.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-6Qvnhd2nhRrIBx6NMf9BJf template-haskell-2.20.0.0
    text-2.0.2 th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

